package hideandseek.utils;

import java.lang.reflect.InvocationTargetException;
import org.bukkit.Bukkit;
import org.bukkit.inventory.meta.PotionMeta;
import org.bukkit.potion.PotionType;
import org.bukkit.inventory.meta.EnchantmentStorageMeta;
import org.bukkit.enchantments.Enchantment;
import org.bukkit.Material;
import java.util.ArrayList;
import java.util.List;
import org.bukkit.inventory.meta.ItemMeta;
import org.bukkit.inventory.ItemStack;
import java.lang.reflect.Method;

public class ItemStackBuilder
{
    public static Method setDamageMethod;
    private final ItemStack item;
    private ItemMeta meta;
    private final List<String> lore;
    
    public ItemStackBuilder(final ItemStack var1) {
        this.item = var1;
        this.meta = var1.getItemMeta();
        this.lore = ((this.meta != null && this.meta.hasLore()) ? this.meta.getLore() : new ArrayList<String>());
    }
    
    public ItemStackBuilder(final Material var1) {
        this(new ItemStack(var1));
    }
    
    public static void loadMethods() {
        try {
            for (final Method var4 : Class.forName("org.bukkit.inventory.meta.Damageable").getMethods()) {
                if (var4.getName().equals("setDamage")) {
                    ItemStackBuilder.setDamageMethod = var4;
                    break;
                }
            }
        }
        catch (final Exception ex) {}
    }
    
    public ItemStackBuilder setType(final Material var1) {
        this.item.setType(var1);
        return this;
    }
    
    public ItemStackBuilder setName(final String var1) {
        this.meta.setDisplayName(var1);
        return this;
    }
    
    public ItemStackBuilder addLore(final String... var1) {
        final String[] var2 = var1;
        for (int var3 = var1.length, var4 = 0; var4 < var3; ++var4) {
            final String var5 = var2[var4];
            this.lore.add(var5);
        }
        return this;
    }
    
    public ItemStackBuilder clearLore() {
        this.lore.clear();
        return this;
    }
    
    public ItemStackBuilder addEnchantment(final Enchantment var1, final int var2) {
        if (this.item.getType().equals((Object)Material.ENCHANTED_BOOK)) {
            ((EnchantmentStorageMeta)this.meta).addStoredEnchant(var1, var2, true);
        }
        else {
            this.meta.addEnchant(var1, var2, true);
        }
        return this;
    }
    
    public ItemStackBuilder setAmount(final int var1) {
        this.item.setAmount(var1);
        return this;
    }
    
    public ItemStackBuilder setDurability(final int var1) {
        if (ItemStackBuilder.setDamageMethod != null) {
            try {
                ItemStackBuilder.setDamageMethod.invoke(this.meta, (short)var1);
            }
            catch (final Exception var2) {
                var2.printStackTrace();
            }
        }
        else {
            this.item.setDurability((short)var1);
        }
        return this;
    }
    
    public void setPotionEffect(final PotionType var1, final boolean var2, final boolean var3) {
        final PotionMeta var4 = (PotionMeta)this.item.getItemMeta();
        try {
            PotionMeta.class.getMethod("setBasePotionData", Class.forName("org.bukkit.potion.PotionData")).invoke(var4, Class.forName("org.bukkit.potion.PotionData").getConstructor(PotionType.class, Boolean.TYPE, Boolean.TYPE).newInstance(var1, var2, var3));
        }
        catch (final IllegalArgumentException | InvocationTargetException | NoSuchMethodException | SecurityException | ClassNotFoundException | InstantiationException | IllegalAccessException var5) {
            Bukkit.getConsoleSender().sendMessage("[躲猫猫] 使用的药水效果不适用于此minecraft版本, 可尝试其他药水效果比如: POTION:DURABILITY");
        }
        this.meta = (ItemMeta)var4;
    }
    
    public ItemStack build() {
        if (this.meta != null) {
            this.meta.setLore((List)this.lore);
        }
        this.item.setItemMeta(this.meta);
        return this.item;
    }
}
